@@ -8,7 +8,7 @@ use Carp qw( croak );
 use Exporter ();
 
 # ABSTRACT: Portably generate config for any shell
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.34'; # VERSION
 
 
 sub new
@@ -158,8 +158,8 @@ sub _value_escape_powershell
 sub set_alias
 {
   my($self, $alias, $command) = @_;
-  
-  push @{ $self->{commands} }, ['alias', $alias, $command]; 
+
+  push @{ $self->{commands} }, ['alias', $alias, $command];
 }
 
 
@@ -174,8 +174,33 @@ sub generate
 {
   my($self, $shell) = @_;
 
-  $shell ||= Shell::Guess->running_shell;
-  
+  if(defined $shell)
+  {
+    if(ref($shell) eq '')
+    {
+      my $method = join '_', $shell, 'shell';
+      if(Shell::Guess->can($method))
+      {
+        $shell = Shell::Guess->$method;
+      }
+      else
+      {
+        croak("unknown shell type: $shell");
+      }
+    }
+  }
+  else
+  {
+    $shell = Shell::Guess->running_shell;
+  }
+
+  $self->_generate($shell);
+}
+
+sub _generate
+{
+  my($self, $shell) = @_;
+
   my $buffer = '';
   my $sep    = $shell->is_win32 ? ';' : ':';
 
@@ -201,7 +226,7 @@ sub generate
       $sep = shift @$args;
       next;
     }
-    
+
     # rewrite set_path as set
     if($command eq 'set_path')
     {
@@ -323,7 +348,7 @@ sub generate
         croak 'don\'t know how to "comment" with ' . $shell->name;
       }
     }
-    
+
     elsif($command eq 'alias')
     {
       if($shell->is_bourne)
@@ -410,7 +435,7 @@ Shell::Config::Generate - Portably generate config for any shell
 
 =head1 VERSION
 
-version 0.29
+version 0.34
 
 =head1 SYNOPSIS
 
@@ -475,7 +500,7 @@ will generate a C<config.cmd> (Windows C<cmd.exe> script) with this:
 =head1 DESCRIPTION
 
 This module provides an interface for specifying shell configurations
-for different shell environments without having to worry about the 
+for different shell environments without having to worry about the
 arcane differences between shells such as csh, sh, cmd.exe and command.com.
 
 It does not modify the current environment, but it can be used to
@@ -564,8 +589,8 @@ the internal portable format stored inside the instance.
 =back
 
 The idea is that you can create multiple modifications
-to the environment without worrying about specific shells, 
-then when you are done you can create shell specific 
+to the environment without worrying about specific shells,
+then when you are done you can create shell specific
 versions of those modifications using the generators.
 
 This may be useful for system administrators that must support
@@ -583,8 +608,8 @@ Set an environment variable.
  $config->set_path( $name => @values );
 
 Sets an environment variable which is stored in standard
-'path' format (Like PATH or PERL5LIB).  In UNIX land this 
-is a colon separated list stored as a string.  In Windows 
+'path' format (Like PATH or PERL5LIB).  In UNIX land this
+is a colon separated list stored as a string.  In Windows
 this is a semicolon separated list stored as a string.
 You can do the same thing using the C<set> method, but if
 you do so you have to determine the correct separator.
@@ -625,7 +650,7 @@ configurations into your shell.
 
 This will generate a shebang at the beginning of the configuration,
 making it appropriate for use as a script.  For non UNIX shells this
-will be ignored.  If specified, $location will be used as the 
+will be ignored.  If specified, C<$location> will be used as the
 interpreter location.  If it is not specified, then the default
 location for the shell will be used.
 
@@ -671,7 +696,7 @@ may be specified.
  $config->set_path_sep( $sep );
 
 Use C<$sep> as the path separator instead of the shell
-default path separator (generally C<:> for Unix shells 
+default path separator (generally C<:> for Unix shells
 and C<;> for Windows shells).
 
 Not all characters are supported, it is usually best
@@ -683,16 +708,22 @@ to stick with the shell default or to use C<:> or C<;>.
  my $command_text = $config->generate( $shell );
 
 Generate shell configuration code for the given shell.
-$shell is an instance of L<Shell::Guess>.  If $shell
+C<$shell> is an instance of L<Shell::Guess>.  If C<$shell>
 is not provided, then this method will use Shell::Guess
 to guess the shell that called your perl script.
 
+You can also pass in the shell name as a string for
+C<$shell>.  This should correspond to the appropriate
+I<name>_shell from L<Shell::Guess>.  So for csh you
+would pass in C<"c"> and for tcsh you would pass in
+C<"tc">, etc.
+
 =head2 generate_file
 
  $config->generate_file( $shell, $filename );
 
 Generate shell configuration code for the given shell
-and write it to the given file.  $shell is an instance 
+and write it to the given file.  C<$shell> is an instance
 of L<Shell::Guess>.  If there is an IO error it will throw
 an exception.
 
@@ -705,8 +736,8 @@ an exception.
 On C<MSWin32> and C<cygwin>:
 
 Given a list of directory paths (or filenames), this will
-return an equivalent list of paths pointing to the same 
-file system objects without spaces.  To do this 
+return an equivalent list of paths pointing to the same
+file system objects without spaces.  To do this
 C<Win32::GetShortPathName()> is used on to find alternative
 path names without spaces.
 
@@ -762,24 +793,24 @@ on csh probably deserve a comment here.  It looks like this:
 
 =item * one line
 
-The command is all on one line, and doesn't use if, which is 
-probably more clear and ideomatic.  This for example, might 
+The command is all on one line, and doesn't use if, which is
+probably more clear and ideomatic.  This for example, might
 make more sense:
 
  if ( $?PATH == 0 ) then
-   setenv PATH '/foo/bar/bin:/bar/foo/bin' 
+   setenv PATH '/foo/bar/bin:/bar/foo/bin'
  else
    setenv PATH "$PATH":'/foo/bar/bin:/bar/foo/bin'
  endif
 
 However, this only works if the code interpreted using the csh
-C<source> command or is included in a csh script inline.  If you 
+C<source> command or is included in a csh script inline.  If you
 try to invoke this code using csh C<eval> then it will helpfully
 convert it to one line and if does not work under csh in one line.
 
 =back
 
-There are probably more clever or prettier ways to 
+There are probably more clever or prettier ways to
 append/prepend path environment variables as I am not a shell
 programmer.  Patches welcome.
 
